@@ -1,6 +1,9 @@
 #![allow(
     clippy::bool_to_int_with_if,
+    clippy::char_lit_as_u8,
+    clippy::deref_addrof,
     clippy::diverging_sub_expression,
+    clippy::erasing_op,
     clippy::extra_unused_type_parameters,
     clippy::if_same_then_else,
     clippy::ifs_same_cond,
@@ -16,6 +19,7 @@
     clippy::redundant_pattern_matching,
     clippy::too_many_lines,
     clippy::unit_arg,
+    clippy::unnecessary_cast,
     clippy::while_immutable_condition,
     clippy::zero_ptr,
     irrefutable_let_patterns
@@ -464,7 +468,9 @@ fn test_trailer() {
 fn test_whitespace() {
     #[derive(Debug)]
     pub struct Point {
+        #[allow(dead_code)]
         pub x: i32,
+        #[allow(dead_code)]
         pub y: i32,
     }
 
